@@ -68,7 +68,8 @@ mIpc_debug(u_int dmask, l3_process_t *pc, char *fmt, ...)
 static void
 l3fi_debug(struct FsmInst *fi, char *fmt, ...)
 {
-	layer3_t *l3 = fi->l3;
+	struct l2l3if *l2i = fi->userdata;
+	layer3_t *l3 = l2i->l3;
 
 	va_list args;
 	char buf[256], *p;
@@ -196,7 +197,7 @@ L3TimerFunction(void *arg)
 static void
 L3TimerInit(layer3_t *l3, int pid, struct L3Timer *t)
 {
-	init_timer(&t->tl, l3, t, L3TimerFunction);
+	init_timer(&t->tl, &l3->tbase, t, L3TimerFunction);
 	t->pid = pid;
 	t->nr = 0;
 	t->l3 = l3;
@@ -440,19 +441,20 @@ lc_connect(struct FsmInst *fi, int event, void *arg)
 	struct l2l3if *l2i = fi->userdata;
 	struct mbuffer	*mb;
 	int dequeued = 0;
-	l3_process_t	*pc;
 
 	FsmChangeState(fi, ST_L3_LC_ESTAB);
 	while ((mb = mdequeue(&l2i->squeue))) {
 		l3down(l2i, DL_DATA_REQ, mb);
 		dequeued++;
 	}
+	dprint(DBGM_L3DATA, "port%d sent %d messages to L2\n",  l2i->l3->l2master.l2addr.dev, dequeued);
 //	pc = get_first_l3process4ces(l2i->l3, l2i->l2addr.channel);
 //	if ((!pc) && (!test_bit(MISDN_FLG_L2_HOLD, &l2i->l3->ml3.options)) && dequeued) {
 //		FsmEvent(fi, EV_RELEASE_REQ, NULL);
 //	} else {
-		l3ml3p(l2i->l3, DL_ESTABLISH_IND, l2i->l2addr.channel);
+//		l3ml3p(l2i->l3, DL_ESTABLISH_IND, l2i->l2addr.channel);
 //	}
+	l3ml3p(l2i->l3, DL_ESTABLISH_IND, l2i->l2addr.channel);
 	l2i->l3->ml3.from_layer3(&l2i->l3->ml3, MT_L2ESTABLISH, l2i->l2addr.tei, NULL);
 }
 
@@ -462,7 +464,6 @@ lc_connected(struct FsmInst *fi, int event, void *arg)
 	struct l2l3if *l2i = fi->userdata;
 	struct mbuffer	*mb;
 	int dequeued = 0;
-	l3_process_t	*pc;
 
 	FsmDelTimer(&l2i->l3m_timer, 51);
 	FsmChangeState(fi, ST_L3_LC_ESTAB);
@@ -470,12 +471,14 @@ lc_connected(struct FsmInst *fi, int event, void *arg)
 		l3down(l2i, DL_DATA_REQ, mb);
 		dequeued++;
 	}
+	dprint(DBGM_L3DATA, "port%d sent %d messages to L2\n",  l2i->l3->l2master.l2addr.dev, dequeued);
 //	pc = get_first_l3process4ces(l2i->l3, l2i->l2addr.channel);
 //	if ((!pc) && (!test_bit(MISDN_FLG_L2_HOLD, &l2i->l3->ml3.options)) && dequeued) {
 //		FsmEvent(fi, EV_RELEASE_REQ, NULL);
 //	} else {
-		l3ml3p(l2i->l3, DL_ESTABLISH_IND, l2i->l2addr.channel);
+//		l3ml3p(l2i->l3, DL_ESTABLISH_IND, l2i->l2addr.channel);
 //	}
+	l3ml3p(l2i->l3, DL_ESTABLISH_IND, l2i->l2addr.channel);
 	l2i->l3->ml3.from_layer3(&l2i->l3->ml3, MT_L2ESTABLISH, l2i->l2addr.tei, NULL);
 }
 
@@ -645,7 +648,7 @@ to_layer3(struct mlayer3 *ml3, unsigned int prim, unsigned int pid, struct l3_ms
 		mqueue_tail(q, mb);
 		id = 0;
 		/* wake up worker */
-		ret = ioctl(l3->mdev, IMADDTIMER, &id);
+		ret = ioctl(l3->tbase.tdev, IMADDTIMER, &id);
 		if (ret)
 			eprint("%s wake up worker error %s\n", __FUNCTION__, strerror(errno));
 	}
@@ -661,7 +664,7 @@ init_l2if(struct l2l3if *l2i, layer3_t *l3)
 	l2i->l3m.fsm = &l3fsm;
 	l2i->l3m.state = ST_L3_LC_REL;
 	l2i->l3m.userdata = l2i;
-	l2i->l3m.l3 = l3;
+	l2i->l3m.tb = &l3->tbase;
 	l2i->l3m.userint = 0;
 	FsmInitTimer(&l2i->l3m, &l2i->l3m_timer);
 	l2i->l3m.printdebug = l3fi_debug;
@@ -701,6 +704,7 @@ void
 init_l3(layer3_t *l3)
 {
 	INIT_LIST_HEAD(&l3->plist);
+	INIT_LIST_HEAD(&l3->tbase.pending_timer);
 	l3->global.l2if = &l3->l2master;
 	l3->global.L3 = l3;
 	l3->dummy.l2if = &l3->l2master;
@@ -720,7 +724,6 @@ init_l3(layer3_t *l3)
 		l3->l2master.l3m.state = ST_L3_LC_ESTAB;
 	mqueue_init(&l3->app_queue);
 	mqueue_init(&l3->mgr_queue);
-	INIT_LIST_HEAD(&l3->pending_timer);
 	l3->ml3.to_layer3 = to_layer3;
 	pthread_mutex_init(&l3->run, NULL);
 	l3->next_cr = 1;
@@ -886,7 +889,7 @@ layer3_thread(void *arg)
 	while(!test_bit(FLG_ABORT, &l3->ml3.options)) {
 		FD_ZERO(&rfd);
 		FD_SET(l3->l2sock, &rfd);
-		FD_SET(l3->mdev, &rfd);
+		FD_SET(l3->tbase.tdev, &rfd);
 		ret = select(l3->maxfd +1, &rfd, NULL, NULL, NULL);
 		if (ret < 0) {
 			if (errno == EINTR)
@@ -894,13 +897,13 @@ layer3_thread(void *arg)
 			eprint("%s aborted: %s\n", __FUNCTION__, strerror(errno));
 			break;
 		}
-		if (FD_ISSET(l3->mdev, &rfd)) {
-			ret = read(l3->mdev, &id, sizeof(id));
+		if (FD_ISSET(l3->tbase.tdev, &rfd)) {
+			ret = read(l3->tbase.tdev, &id, sizeof(id));
 			if (ret < 0) {
 				eprint("%s read timer error %s\n", __FUNCTION__, strerror(errno));
 			} else {
 				if (ret == sizeof(id) && id) {
-					expire_timer(l3, id);
+					expire_timer(&l3->tbase, id);
 				}
 			}
 		}
