@@ -258,6 +258,7 @@ assembleQ931(l3_process_t *pc, struct l3_msg *l3m)
 	for (i=0; i<8; i++) {
 		/* handle other codeset elements */
 		if (l3m->extra[i].codeset) {
+			ie = 0x98 | l3m->extra[i].codeset;
 			*msg_put(mb, 1) = ie; /* shift codeset IE */
 			memcpy(msg_put(mb, l3m->extra[i].len), l3m->extra[i].val, l3m->extra[i].len);
 		}
@@ -390,14 +391,23 @@ mi_encode_channel_id(struct l3_msg *l3m, struct misdn_channel_info *ci)
 		} else {
 			l = 3;
 			ie[0] = 0x80 | 0x20 | (excl << 3) | 1;
-			if (ci->type & MI_CHAN_TYP_H0)
-				ie[1] = 0x86;
-			else if (ci->type & MI_CHAN_TYP_H11)
-				ie[1] = 0x88;
-			else if (ci->type & MI_CHAN_TYP_H12)
-				ie[1] = 0x89;
-			else /* default B-channel */
+			switch (ci->type) {
+			case MI_CHAN_TYP_B: /* most common */
 				ie[1] = 0x83;
+				break;
+			case MI_CHAN_TYP_H0:
+				ie[1] = 0x86;
+				break;
+			case MI_CHAN_TYP_H11:
+				ie[1] = 0x88;
+				break;
+			case MI_CHAN_TYP_H12:
+				ie[1] = 0x89;
+				break;
+			default: /* use B-channel */
+				ie[1] = 0x83;
+				break;
+			}
 			ie[2] = 0x80 | ci->nr;
 		}
 	} else { /* BRI */
@@ -653,7 +663,7 @@ mi_encode_facility(struct l3_msg *l3m, struct asn1_parm *fac)
 	if (len <= 0)
 		return -EINVAL;
 	if (mb->ctail + len >= mb->cend) {
-		eprint("Msg buffer overflow %d needed %ld available\n", len + 1, mb->cend - mb->ctail);
+		eprint("Msg buffer overflow %d needed %d available\n", len + 1, (int)(mb->cend - mb->ctail));
 		return Q931_ERROR_OVERFLOW;
 	}
 	if (l3m->facility) {
@@ -686,6 +696,7 @@ mi_decode_progress(struct l3_msg *l3m, struct misdn_progress_info *progress)
 		return -EINVAL;
 	prg.loc = l3m->progress[1] &  0x7f;
 	prg.desc = l3m->progress[2] & 0x7f;
+	prg.resv = 0;
 	prg.ctrl = MI_PROG_CTRL_UPDATED;
 	_ASSIGN_PVAL(progress, prg);
 	return 0;
@@ -1003,6 +1014,7 @@ mi_decode_redirecting_nr(struct l3_msg *l3m, int *count, int *type, int *plan, i
 	return 0;
 }
 
+int
 mi_decode_redirection_nr(struct l3_msg *l3m, int *type, int *plan, int *pres, char *nr)
 {
 	int _pres = 0, i = 2, l;
